@@ -1,18 +1,63 @@
-
 use strict;
 use warnings;
-
 package HTML::Widget::Plugin::Input;
+{
+  $HTML::Widget::Plugin::Input::VERSION = '0.083';
+}
+use parent 'HTML::Widget::Plugin';
+# ABSTRACT: the most basic input widget
 
-use HTML::Widget::Plugin ();
-BEGIN { our @ISA = 'HTML::Widget::Plugin' };
 
-our $VERSION = '0.082';
+use HTML::Element;
+
+
+sub provided_widgets { qw(input hidden) }
+
+
+sub _attribute_args { qw(disabled type value size maxlength) }
+sub _boolean_args   { qw(disabled) }
+
+sub input {
+  my ($self, $factory, $arg) = @_;
+
+  $self->build($factory, $arg);
+}
+
+
+sub hidden {
+  my ($self, $factory, $arg) = @_;
+
+  $arg->{attr}{type} = 'hidden';
+
+  $self->build($factory, $arg);
+}
+
+
+sub build {
+  my ($self, $factory, $arg) = @_;
+
+  $arg->{attr}{name} = $arg->{attr}{id} unless defined $arg->{attr}{name};
+
+  my $widget = HTML::Element->new('input');
+
+  $widget->attr($_ => $arg->{attr}{$_}) for keys %{ $arg->{attr} };
+  return $widget->as_XML;
+}
+
+1;
+
+__END__
+
+=pod
 
 =head1 NAME
 
 HTML::Widget::Plugin::Input - the most basic input widget
 
+=head1 VERSION
+
+version 0.083
+
 =head1 SYNOPSIS
 
   $widget_factory->input({
@@ -32,20 +77,12 @@ HTML::Widget::Plugin::Input - the most basic input widget
 
 This plugin provides a basic input widget.
 
-=cut
-
-use HTML::Element;
-
 =head1 METHODS
 
 =head2 C< provided_widgets >
 
 This plugin provides the following widgets: input, hidden
 
-=cut
-
-sub provided_widgets { qw(input hidden) }
-
 =head2 C< input >
 
 This method returns a basic one-line text-entry widget.
@@ -66,17 +103,6 @@ different plugin, instead.
 
 =back
 
-=cut
-
-sub _attribute_args { qw(disabled type value size maxlength) }
-sub _boolean_args   { qw(disabled) }
-
-sub input {
-  my ($self, $factory, $arg) = @_;
-
-  $self->build($factory, $arg);
-}
-
 =head2 C< hidden >
 
 This method returns a hidden input that is not displayed in the rendered HTML.
@@ -84,16 +110,6 @@ Its arguments are the same as those to C<input>.
 
 This method may later be factored out into a plugin.
 
-=cut
-
-sub hidden {
-  my ($self, $factory, $arg) = @_;
-
-  $arg->{attr}{type} = 'hidden';
-
-  $self->build($factory, $arg);
-}
-
 =head2 C< build >
 
   my $widget = $class->build($factory, $arg);
@@ -102,28 +118,15 @@ This method does the actual construction of the input based on the args
 collected by the widget-constructing method.  It is primarily here for
 subclasses to exploit.
 
-=cut
-
-sub build {
-  my ($self, $factory, $arg) = @_;
-
-  $arg->{attr}{name} = $arg->{attr}{id} unless defined $arg->{attr}{name};
-
-  my $widget = HTML::Element->new('input');
-
-  $widget->attr($_ => $arg->{attr}{$_}) for keys %{ $arg->{attr} };
-  return $widget->as_XML;
-}
-
 =head1 AUTHOR
 
-Ricardo SIGNES <C<rjbs @ cpan.org>>
+Ricardo SIGNES
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005-2007, Ricardo SIGNES.  This is free software, released under
-the same terms as perl itself.
+This software is copyright (c) 2005 by Ricardo SIGNES.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
