@@ -1,17 +1,47 @@
 use strict;
 use warnings;
-
 package HTML::Widget::Plugin::Password;
+{
+  $HTML::Widget::Plugin::Password::VERSION = '0.083';
+}
+use parent 'HTML::Widget::Plugin::Input';
+# ABSTRACT: for SECRET input
 
-use HTML::Widget::Plugin::Input ();
-BEGIN { our @ISA = 'HTML::Widget::Plugin::Input' };
 
-our $VERSION = '0.082';
+use HTML::Element;
+
+
+sub provided_widgets { [ input => 'password' ] }
+
+
+
+sub rewrite_arg {
+  my ($self, $arg) = @_;
+
+  $arg = $self->SUPER::rewrite_arg($arg);
+
+  $arg->{attr}{type} = "password";
+
+  $arg->{attr}{value} = q{ } x 8
+    if defined $arg->{attr}{value} and length $arg->{attr}{value};
+
+  return $arg;
+}
+
+1;
+
+__END__
+
+=pod
 
 =head1 NAME
 
 HTML::Widget::Plugin::Password - for SECRET input
 
+=head1 VERSION
+
+version 0.083
+
 =head1 SYNOPSIS
 
   $widget_factory->password({
@@ -23,20 +53,12 @@ HTML::Widget::Plugin::Password - for SECRET input
 
 This plugin provides a widget for password-entry inputs.
 
-=cut
-
-use HTML::Element;
-
 =head1 METHODS
 
 =head2 C< provided_widgets >
 
 This plugin provides the following widgets: password
 
-=cut
-
-sub provided_widgets { [ input => 'password' ] }
-
 =head2 C< password >
 
 This method returns a password-entry widget.
@@ -53,37 +75,20 @@ series of spaces, if the value is defined.
 
 =back
 
-=cut
-
 =head2 C< rewrite_arg >
 
 The password plugin's rewrite_arg replaces any non-empty value with a string of
 spaces so that passwords are not inadvertantly sent as plain text.
 
-=cut
-
-sub rewrite_arg {
-  my ($self, $arg) = @_;
-
-  $arg = $self->SUPER::rewrite_arg($arg);
-
-  $arg->{attr}{type} = "password";
-
-  $arg->{attr}{value} = q{ } x 8
-    if defined $arg->{attr}{value} and length $arg->{attr}{value};
-
-  return $arg;
-}
-
 =head1 AUTHOR
 
-Ricardo SIGNES <C<rjbs @ cpan.org>>
+Ricardo SIGNES
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005-2007, Ricardo SIGNES.  This is free software, released under
-the same terms as perl itself.
+This software is copyright (c) 2005 by Ricardo SIGNES.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
