@@ -1,17 +1,99 @@
 use strict;
 use warnings;
-
 package HTML::Widget::Plugin::Select;
+{
+  $HTML::Widget::Plugin::Select::VERSION = '0.083';
+}
+use parent 'HTML::Widget::Plugin';
+# ABSTRACT: a widget for selection from a list
 
-use HTML::Widget::Plugin ();
-BEGIN { our @ISA = 'HTML::Widget::Plugin' };
 
-our $VERSION = '0.082';
+sub provided_widgets { qw(select) }
+
+
+use HTML::Element;
+
+sub _attribute_args { qw(disabled) }
+sub _boolean_args   { qw(disabled) }
+
+sub select { ## no critic Builtin
+  my ($self, $factory, $arg) = @_;
+
+  $self->build($factory, $arg);
+}
+
+
+sub build {
+  my ($self, $factory, $arg) = @_;
+  $arg->{attr}{name} = $arg->{attr}{id} unless $arg->{attr}{name};
+
+  my $widget = HTML::Element->new('select');
+
+  my @options;
+  if (ref $arg->{options} eq 'HASH') {
+    @options = map { [ $_, $arg->{options}{$_} ] } keys %{ $arg->{options} };
+  } else {
+    @options = @{ $arg->{options} };
+    Carp::croak "undefined value passed to select widget"
+      if grep { not(defined $_) or ref $_ and not defined $_->[0] } @options;
+  }
+
+  $self->validate_value($arg->{value}, \@options) unless $arg->{ignore_invalid};
+
+  for my $entry (@options) {
+    my ($value, $name) = (ref $entry) ? @$entry : ($entry) x 2;
+    my $option = $self->make_option($factory, $value, $name, $arg);
+    $widget->push_content($option);
+  }
+
+  $widget->attr($_ => $arg->{attr}{$_}) for keys %{ $arg->{attr} };
+  return $widget->as_XML;
+}
+
+
+sub make_option {
+  my ($self, $factory, $value, $name, $arg) = @_;
+
+  my $option = HTML::Element->new('option', value => $value);
+     $option->push_content($name);
+     $option->attr(selected => 'selected')
+       if defined $arg->{value} and $arg->{value} eq $value;
+
+  return $option;
+}
+
+
+sub validate_value {
+  my ($class, $value, $options) = @_;
+
+  my @options = map { ref $_ ? $_->[0] : $_ } @$options;
+  # maybe this should be configurable?
+  if ($value) {
+    my $matches = grep { $value eq $_ } @options;
+
+    if (not $matches) {
+      Carp::croak "provided value '$value' not in given options: "
+                . join(q{ }, map { "'$_'" } @options);
+    } elsif ($matches > 1) {
+      Carp::croak "provided value '$matches' matches more than one option";
+    }
+  }
+}
+
+1;
+
+__END__
+
+=pod
 
 =head1 NAME
 
 HTML::Widget::Plugin::Select - a widget for selection from a list
 
+=head1 VERSION
+
+version 0.083
+
 =head1 SYNOPSIS
 
   $widget_factory->select({
@@ -34,10 +116,6 @@ This plugin provides a select-from-list widget.
 
 This plugin provides the following widgets: select
 
-=cut
-
-sub provided_widgets { qw(select) }
-
 =head2 C< select >
 
 This method returns a select-from-list widget.
@@ -75,19 +153,6 @@ has this value.
 
 =back
 
-=cut
-
-use HTML::Element;
-
-sub _attribute_args { qw(disabled) }
-sub _boolean_args   { qw(disabled) }
-
-sub select { ## no critic Builtin
-  my ($self, $factory, $arg) = @_;
-
-  $self->build($factory, $arg);
-}
-
 =head2 C< build >
 
  my $widget = $class->build($factory, \%arg)
@@ -95,35 +160,6 @@ sub select { ## no critic Builtin
 This method does the actual construction of the widget based on the args set up
 in the exported widget-constructing call.  It's here for subclasses to exploit.
 
-=cut
-
-sub build {
-  my ($self, $factory, $arg) = @_;
-  $arg->{attr}{name} = $arg->{attr}{id} unless $arg->{attr}{name};
-
-  my $widget = HTML::Element->new('select');
-
-  my @options;
-  if (ref $arg->{options} eq 'HASH') {
-    @options = map { [ $_, $arg->{options}{$_} ] } keys %{ $arg->{options} };
-  } else {
-    @options = @{ $arg->{options} };
-    Carp::croak "undefined value passed to select widget"
-      if grep { not(defined $_) or ref $_ and not defined $_->[0] } @options;
-  }
-
-  $self->validate_value($arg->{value}, \@options) unless $arg->{ignore_invalid};
-
-  for my $entry (@options) {
-    my ($value, $name) = (ref $entry) ? @$entry : ($entry) x 2;
-    my $option = $self->make_option($factory, $value, $name, $arg);
-    $widget->push_content($option);
-  }
-
-  $widget->attr($_ => $arg->{attr}{$_}) for keys %{ $arg->{attr} };
-  return $widget->as_XML;
-}
-
 =head2 C< make_option >
 
   my $option = $class->make_option($factory, $value, $name, $arg);
@@ -132,52 +168,20 @@ This method constructs the HTML::Element option element that will represent one
 of the options that may be put into the select box.  This is here for
 subclasses to exploit.
 
-=cut
-
-sub make_option {
-  my ($self, $factory, $value, $name, $arg) = @_;
-
-  my $option = HTML::Element->new('option', value => $value);
-     $option->push_content($name);
-     $option->attr(selected => 'selected')
-       if defined $arg->{value} and $arg->{value} eq $value;
-
-  return $option;
-}
-
 =head2 C< validate_value >
 
 This method checks whether the given value option is valid.  See C<L</select>>
 for an explanation of its default rules.
 
-=cut
-
-sub validate_value {
-  my ($class, $value, $options) = @_;
-
-  my @options = map { ref $_ ? $_->[0] : $_ } @$options;
-  # maybe this should be configurable?
-  if ($value) {
-    my $matches = grep { $value eq $_ } @options;
-
-    if (not $matches) {
-      Carp::croak "provided value '$value' not in given options: "
-                . join(q{ }, map { "'$_'" } @options);
-    } elsif ($matches > 1) {
-      Carp::croak "provided value '$matches' matches more than one option";
-    }
-  }
-}
-
 =head1 AUTHOR
 
-Ricardo SIGNES <C<rjbs @ cpan.org>>
+Ricardo SIGNES
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2005-2007, Ricardo SIGNES.  This is free software, released under
-the same terms as perl itself.
+This software is copyright (c) 2005 by Ricardo SIGNES.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-1;
